@@ -35,15 +35,21 @@ def display_apps_infos(config: Dict) -> None:
     for app, info in config.items():
         data_list.append([app, info["dir"], info["status"]])
 
-    dash = "-" * 125
+    left_len = max(list(map(lambda x: len(x[0]), data_list))) + 5
+    middle_len = max(list(map(lambda x: len(x[1]), data_list))) + 5
+    right_len = max(list(map(lambda x: len(x[2]), data_list))) + 5
+
+    dash = "-" * (left_len + middle_len + right_len)
+    # conditionnal number of space based on string size
+    space_string = "{:<%ds}{:^%ds}{:>%ds}" % (left_len, middle_len, right_len)
 
     for i, data in enumerate(data_list):
         if i == 0:
             print(dash)
-            print("{:<20s}{:^90s}{:>15s}".format(data[0], data[1], data[2]))
+            print(space_string.format(data[0], data[1], data[2]))
             print(dash)
         else:
-            print("{:<20s}{:^90s}{:>15s}".format(data[0], data[1], data[2]))
+            print(space_string.format(data[0], data[1], data[2]))
 
     return
 
@@ -221,11 +227,11 @@ def get_app_scorenames(app_name: str) -> List[str]:
     names via a @staticmethod
     """
     app_dir = get_app_info(app_name)
-    app_dir = Path(app_dir)
+    app_dir = Path(app_dir)  # type: ignore
 
-    sys.path.append(str(app_dir.parent))
+    sys.path.append(str(app_dir.parent))  # type: ignore
     mod = importlib.import_module(app_name + ".src.app")
-    scores = mod.App.score_names()
+    scores = mod.App.score_names()  # type: ignore
     # Remove last element of the path which was added manually
     sys.path.pop(-1)
 
