@@ -82,7 +82,7 @@ class DeployCommand(BaseCLICommand):
                 return
 
         score_configuration = get_app_scorenames(app_name)
-        req = upload_code(app_dir, app_name, pat, url, score_configuration)
+        req = upload_code(app_dir, app_name, pat, f"{url}/apps/", score_configuration)
 
         if req.status_code != 200:
             log.warning("api return %s stopping operation.", req.status_code)
@@ -94,7 +94,7 @@ class DeployCommand(BaseCLICommand):
 
         if self.checkpoint:
             _check_checkpoint_files(app_name)
-            req = upload_checkpoint(app_dir, app_name, pat, url, configuration["size_limit"])
+            req = upload_checkpoint(app_dir, app_name, pat, f"{url}/apps/", configuration["size_limit"])
             if req.status_code != 200:
                 log.warning("api return %s stopping operation", req.status_code)
                 log.warning("Checkpoint not uploaded.")
